var dir_8d734bf48796b8afc2ea3e50ddaea273 =
[
    [ "amg_operations.hpp", "host__based_2amg__operations_8hpp.html", "host__based_2amg__operations_8hpp" ],
    [ "common.hpp", "linalg_2host__based_2common_8hpp.html", "linalg_2host__based_2common_8hpp" ],
    [ "direct_solve.hpp", "host__based_2direct__solve_8hpp.html", "host__based_2direct__solve_8hpp" ],
    [ "fft_operations.hpp", "host__based_2fft__operations_8hpp.html", "host__based_2fft__operations_8hpp" ],
    [ "ilu_operations.hpp", "host__based_2ilu__operations_8hpp.html", "host__based_2ilu__operations_8hpp" ],
    [ "iterative_operations.hpp", "host__based_2iterative__operations_8hpp.html", "host__based_2iterative__operations_8hpp" ],
    [ "matrix_operations.hpp", "host__based_2matrix__operations_8hpp.html", "host__based_2matrix__operations_8hpp" ],
    [ "misc_operations.hpp", "host__based_2misc__operations_8hpp.html", "host__based_2misc__operations_8hpp" ],
    [ "nmf_operations.hpp", "host__based_2nmf__operations_8hpp.html", "host__based_2nmf__operations_8hpp" ],
    [ "scalar_operations.hpp", "host__based_2scalar__operations_8hpp.html", "host__based_2scalar__operations_8hpp" ],
    [ "sparse_matrix_operations.hpp", "host__based_2sparse__matrix__operations_8hpp.html", "host__based_2sparse__matrix__operations_8hpp" ],
    [ "spgemm_vector.hpp", "spgemm__vector_8hpp.html", "spgemm__vector_8hpp" ],
    [ "vector_operations.hpp", "host__based_2vector__operations_8hpp.html", "host__based_2vector__operations_8hpp" ]
];